@@ -35,7 +35,7 @@
  * $text	The details of the message
  * $cancel	T/F show a cancel button that uses return_referrer()
  */
-function show_confirmation($title,$text,$next_url,$cancel=0) {
+function show_confirmation($title,$text,$next_url,$cancel=0,$form_name='confirmation') {
 
 	if (substr_count($next_url,Config::get('web_path'))) {
 		$path = $next_url;
@@ -184,6 +184,9 @@ function show_header() {
 function show_footer() {
 
 	require_once Config::get('prefix') . '/templates/footer.inc.php';
+	if ($_REQUEST['profiling']) {
+	  Dba::show_profile();
+	}
 
 } // show_footer
 
@@ -248,7 +251,7 @@ function img_resize($image,$size,$type,$album_id) {
 	switch ($type) {
 		case 'jpg':
 		case 'jpeg':
-			imagejpeg($img,null,100);
+			imagejpeg($img,null,75);
 			break;
 		case 'gif':
 			imagegif($img);
@@ -275,28 +278,6 @@ function img_resize($image,$size,$type,$album_id) {
 
 } // img_resize
 
-/**
- * show_genres
- * this shows the 'many' genre form, it takes an array of genre objects and the view object
- */
-function show_genres($genres,$view) {
-
-	require Config::get('prefix') . '/templates/show_genres.inc.php';
-
-} // show_genres
-
-/**
- * show_genre
- * this shows a single genre item which is basicly just a link to the albums/artists/songs of said genre
- */
-function show_genre($genre_id) {
-
-	$genre = new Genre($genre_id);
-
-	require Config::get('prefix') . '/templates/show_genre.inc.php';
-
-} // show_genre
-
 /**
  * get_location
  * This function gets the information about said persons currently location
@@ -526,49 +507,6 @@ function show_artist_select($name='artist', $artist_id=0, $allow_add=0, $song_id
 
 } // show_artist_select
 
-/**
- * show_genre_select
- * It's amazing we have three of these funtions now, this one shows a select of genres and take s name
- * and a selected genre... Woot!
- */
-function show_genre_select($name='genre',$genre_id=1,$size='', $allow_add=0, $song_id=0) { 
-	// Generate key to use for HTML element ID
-	static $id_cnt;
-	if ($song_id) {
-		$key = "genre_select_$song_id";
-	} else {
-		$key = "genre_select_c" . ++$id_cnt;
-	}
-
-        if ($size > 0) {
-                $multiple_txt = " multiple=\"multiple\" size=\"$size\"";
-        }
-
-	echo "<select name=\"$name\"$multiple_txt id=\"$key\">\n";
-
-	$sql = "SELECT `id`, `name` FROM `genre` ORDER BY `name`";
-	$db_results = Dba::query($sql);
-
-	while ($r = Dba::fetch_assoc($db_results)) { 
-		$selected = '';
-		$genre_name = $r['name'];
-		if ($r['id'] == $genre_id) { 
-			$selected = "selected=\"selected\"";
-		}
-	
-		echo "\t<option value=\"" . $r['id'] . "\" $selected>" . scrub_out($genre_name) . "</option>\n";
-	
-	} // end while
-
-	if ($allow_add) {
-		// Append additional option to the end with value=-1
-		echo "\t<option value=\"-1\">Add New...</option>\n";
-	}
-
-	echo "</select>\n";
-
-} // show_genre_select
-
 /**
  * show_catalog_select
  * Yet another one of these buggers. this shows a drop down of all of your catalogs 
@@ -590,6 +528,7 @@ function show_catalog_select($name='catalog',$catalog_id=0,$style='') {
 
 	} // end while
 
+	echo "\t<option value=\"-1\" $selected>All</option>\n";
 	echo "</select>\n";
 
 } // show_catalog_select
@@ -686,7 +625,7 @@ function get_user_icon($name,$title='',$id='') {
 		$name = $name['0']; 
 	} 
 
-	if (!$title) { $title = $name; } 
+	if (!$title) { $title = _(ucfirst($name)); } 
 
 	if ($id) { 
 		$id_element = 'id="' . $id . '"'; 
@@ -730,7 +669,7 @@ function get_user_icon($name,$title='',$id='') {
 
 	} // end if not cached
 
-	$string = "<img src=\"$img_url\" $id_element alt=\"" . ucfirst($title) . "\" title=\"" . ucfirst($title) . "\" $hov_txt/>";
+	$string = "<img src=\"$img_url\" $id_element alt=\"" . $title . "\" title=\"" . $title . "\" $hov_txt/>";
 
 	return $string;
 
@@ -838,12 +777,13 @@ function xml_get_header($type){
 	break;
 	case 'xspf':
                 $header = "<?xml version=\"1.0\" encoding=\"utf-8\" ?>\n" .
-                	  "<playlist version = \"1\" xmlns=\"http://xspf.org/ns/0/\">\n ".
-                	  "<title>Ampache XSPF Playlist</title>\n" .
-                	  "<creator>" . Config::get('site_title') . "</creator>\n" .
-                	  "<annotation>" . Config::get('site_title') . "</annotation>\n" .
-                	  "<info>". Config::get('web_path') ."</info>\n" .
-                	  "<trackList>\n\n\n\n";
+			"<!-- XML Generated by Ampache v." .  Config::get('version') . " -->"; 
+                	"<playlist version = \"1\" xmlns=\"http://xspf.org/ns/0/\">\n ".
+                	"<title>Ampache XSPF Playlist</title>\n" .
+                	"<creator>" . Config::get('site_title') . "</creator>\n" .
+                	"<annotation>" . Config::get('site_title') . "</annotation>\n" .
+	               	"<info>". Config::get('web_path') ."</info>\n" .
+                	"<trackList>\n\n\n\n";
 		return $header;	
 	break;
 	default:
@@ -905,5 +845,21 @@ function toggle_visible($element) {
 
 } // toggle_visible
 
+/**
+ * show_now_playing
+ * This shows the now playing templates and does some garbage colleciont
+ * this should really be somewhere else
+ */
+function show_now_playing() { 
+	
+	Stream::gc_session(); 
+	Stream::gc_now_playing(); 
+
+	$web_path = Config::get('web_path'); 
+	$results = Stream::get_now_playing(); 
+	require_once Config::get('prefix') . '/templates/show_now_playing.inc.php'; 
+
+} // show_now_playing
+
 
 ?>
